<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Activar l’ajuston',
	'aide_non_disponible' => 'Aquela part de l’ajuda en linha es pas encara disponibla per aquesta lenga.',
	'auteur' => 'Autor :',
	'avis_acces_interdit' => 'Accès proïbit.',
	'avis_article_modifie' => 'Atencion, @nom_auteur_modif@ a trabalhat sus aquel article fa @date_diff@ minutas',
	'avis_aucun_resultat' => 'Pas cap de resultat.',
	'avis_chemin_invalide_1' => 'Lo camin qu’avètz causit',
	'avis_chemin_invalide_2' => 'sembla pas valid. Volgatz tornar a la pagina anteriora per verificar las informacions fornidas.',
	'avis_connexion_echec_1' => 'La connexion al servidor SQL a abocat.', # MODIF
	'avis_connexion_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qu’avètz fornidas.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sus plan de servidors, devètz <b>demandar</b> qu’activen vòstre accès a la basa SQL abans de la poder utilizar. Se vos podètz pas connectar, verificatz qu’ajatz plan realizat aquel procediment.', # MODIF
	'avis_connexion_ldap_echec_1' => 'La connexion al servidor LDAP a abocat.',
	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qu’avètz fornidas. ',
	'avis_connexion_ldap_echec_3' => 'Alternativament, utilizetz pas lo supòrt LDAP per importar d’utilizaires.',
	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, voldretz ben oscar aquela casa de confirmacion.',
	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
	'avis_espace_interdit' => '<b>Espaci proïbit</b> <div>SPIP es ja installat.</div>',
	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion a pas pogut legir los noms de las basas de donadas installadas.',
	'avis_lecture_noms_bases_2' => 'Siá cap de basa es pas disponibla, siá la foncion que permet d’entierar las basas es estada desactivada per de rasons de seguretat (aquò’s lo cas en cò de mai d’un albergador).',
	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta lo vòstre nom de login siá utilizabla:',
	'avis_non_acces_page' => 'Podètz pas accedir a aquela pagina.',
	'avis_operation_echec' => 'L’operacion a abocat.',
	'avis_operation_impossible' => 'Operacion impossibla',
	'avis_suppression_base' => 'ATENCION, suprimir las donadas es irreversible',

	// B
	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
	'bouton_ajouter' => 'Apondre',
	'bouton_annuler' => 'Anullar',
	'bouton_demande_publication' => 'Demandar la publicacion d’aqueste article',
	'bouton_desactive_tout' => 'Desactivar tot',
	'bouton_desinstaller' => 'Desinstallar',
	'bouton_effacer_tout' => 'O escafar tot',
	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Afichar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tièra dels redactors connectats',
	'bouton_radio_envoi_annonces_adresse' => 'Mandar los anoncis a l’adreiça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tièra de las novetats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Aparéisser pas dins la tièra dels redactors',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Mandar pas d’anoncis editorials',
	'bouton_redirection' => 'TORNAR DIRIGIR',
	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Ensajar de reparar',
	'bouton_test_proxy' => 'Ensajar lo proxy',
	'bouton_vider_cache' => 'Vojar l’escondedor',

	// C
	'cache_modifiable_webmestre' => 'Lo webmèstre del sit pòt modificar aqueste paramètre.',
	'calendrier_synchro' => 'S’utilizatz un logicial d’agenda compatible <b>iCal</b>, lo podètz sincronizar amb las informacions d’aqueste sit.',
	'config_activer_champs' => 'Activar los camps seguents',
	'config_info_logos' => 'Cada element del sit pòt téner un lògo, e mai un « lògo de subrevòl »',
	'config_info_logos_utiliser' => 'Emplegar los lògos',
	'config_info_logos_utiliser_non' => 'Emplegar pas los lògos',
	'config_info_logos_utiliser_survol' => 'Emplegar los lògos de subrevòl',
	'config_info_logos_utiliser_survol_non' => 'Emplegar pas los lògos de subrevòl',
	'config_info_redirection' => 'En activar aquela opcion, vous poirretz crear d’articles virtuals, que son de referéncias a d’articles publicats sus d’autres sits o fòra  SPIP.',
	'config_redirection' => 'Articles virtuals',
	'connexion_ldap' => 'Conexion :',

	// D
	'date_mot_heures' => 'oras',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adreiça de l’annuari',
	'entree_adresse_email' => 'Vòstra adreiça e-mail',
	'entree_base_donnee_1' => 'Adreiça de la basa de donadas',
	'entree_base_donnee_2' => '(Sovent, aquela adreiça correspond a la del vòstre sit, de còps correspond a la mençon "localhost", de còps, se daissa vuèja completament.)',
	'entree_biographie' => 'Biografia braca, en qualques mots.',
	'entree_chemin_acces' => '<b>Intrar</b> lo camin d’accès:',
	'entree_cle_pgp' => 'La vòstra clau PGP',
	'entree_contenu_rubrique' => '(Contengut de la rubrica en qualques mots.)',
	'entree_identifiants_connexion' => 'Vòstres identificants de connexion...',
	'entree_informations_connexion_ldap' => 'Volgatz intrar dins aquel formulari las informacions de connexion al vòstre annuari LDAP.
L’administrator del sistèma o de la ret vos deu poder fornir
 aquelas informacions.',
	'entree_infos_perso' => 'Qual sètz?',
	'entree_interieur_rubrique' => 'Dintre la rubrica:',
	'entree_liens_sites' => '<b>Ligam ipertèxt</b> (referéncia, sit de vesitar...)',
	'entree_login' => 'Lo vòstre login',
	'entree_login_connexion_1' => 'Lo login de connexion',
	'entree_login_connexion_2' => '(Correspond de còps al vòstre login d’accès a l’FTP; de còps se daissa vuèg)',
	'entree_mot_passe' => 'Vòstre senhal',
	'entree_mot_passe_1' => 'Senhau per la connexion',
	'entree_mot_passe_2' => '(Correspond de còps a vòstre senhal per l’FTP; de còps se daissa vuèg)',
	'entree_nom_fichier' => 'Volgatz intrar lo nom del fichièr @texte_compresse@:',
	'entree_nom_pseudo' => 'Vòstre nom o vòstre pseudonim',
	'entree_nom_pseudo_1' => '(Vòstre nom o vòstre pseudonim)',
	'entree_nom_site' => 'Lo nom del vòstre sit',
	'entree_nouveau_passe' => 'Senhal novèl',
	'entree_passe_ldap' => 'Senhau',
	'entree_port_annuaire' => 'Lo numèro de pòrt de l’annuari',
	'entree_signature' => 'Signatura',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatòri]<br />',
	'entree_url' => 'L’adreiça (URL) del vòstre sit',
	'erreur_plugin_fichier_absent' => 'Fichièr absent',
	'erreur_plugin_fichier_def_absent' => 'Fichièr de definicion absent',
	'erreur_plugin_nom_fonction_interdit' => 'Nom de foncion enebit',
	'erreur_plugin_nom_manquant' => 'Nom d’ajuston mancant',
	'erreur_plugin_prefix_manquant' => 'Espaci de nommatge de l’ajuston non definit',
	'erreur_plugin_tag_plugin_absent' => '&lt;ajuston&gt; mancant dins lo fichièr de definicion',
	'erreur_plugin_version_manquant' => 'Version de l’ajuston mancanta',

	// I
	'ical_info1' => 'Aquela pagina mòstra de metòdes diferents per demorar en contacte amb la vida d’aquel sit.',
	'ical_info2' => 'Per téner mai d’informacions subre aquelas tecnicas, esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'I a dos calendièrs a la vòstra disposicion. Lo primièr es un plan del sit qu’anóncia totes los articles publicats. Lo segond conten los anoncis editorials en mai de vòstres darrièrs messatges privats: vos es reservat gràcias a una clau personala, que la podètz modificar en tot moment en renovant vòstre mot de santa Clara. ',
	'ical_methode_http' => 'Telecargament',
	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
	'ical_texte_js' => 'Los articles publicats en aquel sit se pòdon afichar aisit, dins totes los sits vòstres, en far servir una linha javascript. ',
	'ical_texte_prive' => 'Aquel calendièr, d’us estrictament personal, vos informa de l’activitat editoriala privada d’aquel sit (òbras e rendètz-vos personals, articles e brèvas prepausats...).',
	'ical_texte_public' => 'Aquel calendièr vos permet de seguir l’activitat publica d’aquel sit (articles e brèvas publicats).',
	'ical_texte_rss' => 'Podètz sindicar las novetats d’aqueste sit dins quin legidor de fichièrs que siá en format XML/RSS (Rich Site Summary). Es tanben lo format que permet a SPIP de legir las novetats publicadas dins d’autres sits en utilizar un format d’escambi compatible (sits sindicats). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de corrièr',
	'ical_titre_rss' => 'Fichièrs de sindicacion',
	'icone_activer_cookie' => 'Activar lo cookie de correspondéncia',
	'icone_admin_plugin' => 'Gestion dels ajustons',
	'icone_afficher_auteurs' => 'Afichar los autors',
	'icone_afficher_visiteurs' => 'Afichar los vesitaires',
	'icone_arret_discussion' => 'Quitar aquela discussion',
	'icone_calendrier' => 'Calendièr',
	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo ligar a aquel article',
	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
	'icone_modifier_article' => 'Modificar aquel article',
	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_supprimer_cookie' => 'Suprimir lo cookie de correspondéncia',
	'icone_supprimer_rubrique' => 'Suprimir aquela rubrica',
	'icone_supprimer_signature' => 'Suprimir aquela signatura',
	'icone_valider_signature' => 'Validar aquela signatura',
	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 article',
	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisit del sit public al sit privat.',
	'info_administrateur' => 'Administrator',
	'info_administrateur_1' => 'Administrator',
	'info_administrateur_2' => 'del sit(<i>d’utilizar amb precaucion</i>)',
	'info_administrateur_site_01' => 'Se sètz administrator/tritz del sit, volgatz',
	'info_administrateur_site_02' => 'clicar aquel ligam',
	'info_administrateurs' => 'Administrators',
	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'info_adresse' => 'a l’adreiça:',
	'info_adresse_url' => 'Adreiça (URL) del sit public',
	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
	'info_ajout_image' => 'Quand apondètz d’imatges coma estacaments jonches a un article, SPIP pòt crear automaticament per vos de vinhetas (miniaturas) dels imatges inserits. Aquò permet per exemple de crear automaticament una galariá o un pòrtfòlio.',
	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
	'info_annonce_nouveautes' => 'Anonci de las novetats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Los articles pòstdatats per paréisser',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Los articles d’aquel autor',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Vòstres articles en espèra de validacion',
	'info_aujourdhui' => 'uèi :',
	'info_auteurs' => 'Los autors',
	'info_auteurs_par_tri' => 'autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autentificacion extèrna',
	'info_avertissement' => 'Avís',
	'info_base_installee' => 'L’estructura de vòstra basa de donadas es installada.',
	'info_chapeau' => 'Capèl',
	'info_chapeau_2' => 'Capèl :',
	'info_chemin_acces_1' => 'Opcions : <b>camin d’accès dins l’annuari</b>',
	'info_chemin_acces_2' => 'Ara devètz configurar lo camin d’accès a las informacions dins l’annuari.',
	'info_chemin_acces_annuaire' => 'Opcions:<b>camin d’accès dins l’annuari',
	'info_choix_base' => 'Tresena estapa:',
	'info_classement_1' => '<sup>ièr</sup> de @liste@',
	'info_classement_2' => '<sup>nd</sup> de @liste@',
	'info_code_acces' => 'Oblidetz pas vòstres còdes d’accès pròpris !',
	'info_config_suivi' => 'S’aquela adreiça correspond a una lista de corrièr, podètz indicar çai jos l’adreiça ont los participants al sit se pòdon inscriure. Aquela adreiça pòt èstre una URL (per exemple la pagina d’inscripcion a la lista pel web), o una adreiça e-mail tenent un subjècte especific (per exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Vos podètz abonar a la lista de difusion d’aqueste sit. Alara recebretz per e-mail los anoncis d’articles e de brèvas que se prepausa a la publicacion.',
	'info_confirmer_passe' => 'Confirmar aquel senhal novèl :',
	'info_connexion_base' => 'Ensag de connexion a la basa',
	'info_connexion_ldap_ok' => 'La connexion LDAP a capitat.</b><p> Podètz passar a l’estapa seguenta.</p>', # MODIF
	'info_connexion_mysql' => 'Vòstra connexion SQL',
	'info_connexion_ok' => 'La connexion a capitat.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contengut dels articles',
	'info_creation_paragraphe' => '(Per crear de paragrafes, basta que daissetz de linhas vuèjas.)', # MODIF
	'info_creation_rubrique' => 'Abans de poder escriure d’articles,<br /> devètz crear almens una rubrica.<br />',
	'info_creation_tables' => 'Creacion de las taulas de la basa',
	'info_creer_base' => '<b>Crear</b> una basa de donadas novèla:',
	'info_dans_rubrique' => 'Dins la rubrica :',
	'info_date_publication_anterieure' => 'Data de redaccion anteriora:',
	'info_date_referencement' => 'DATA DE REFERÉNCIAMENT D’AQUEL SIT:',
	'info_derniere_etape' => 'Es acabat!',
	'info_descriptif' => 'Descriptiu :',
	'info_desinstaller_plugin' => 'suprimís las donadas et desactiva l’ajuston ',
	'info_discussion_cours' => 'Discussions en cors',
	'info_ecrire_article' => 'Abans de poder escriure d’articles, vos cal crear almens una rubrica.',
	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcional)',
	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar los e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça de mandadís):',
	'info_email_webmestre' => 'Adreiça e-mail del responsable del sit (opcional)', # MODIF
	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
	'info_envoyer_maintenant' => 'Mandar ara',
	'info_etape_suivante' => 'Passar a l’estapa seguenta',
	'info_etape_suivante_1' => 'Podètz passar a l’estapa seguenta.',
	'info_etape_suivante_2' => 'Podètz passar a l’estapa seguenta.',
	'info_exportation_base' => 'exportacion de la basa cap a @archive@',
	'info_facilite_suivi_activite' => 'Per facilitar lo seguit de l’activitat editoriala del sit, SPIP vos pòt fornir per e-mail, per exemple a una lista de corrièr dels redactors, l’anonci de las demandas de publicacion e de las validacions d’articles.', # MODIF
	'info_fichiers_authent' => 'Fichièrs d’autentificacion « .htpasswd »',
	'info_forums_abo_invites' => 'Vòstre sit web porgís de forums pels abonats; dins lo sit public los vesitaires son convidats a se registrar.',
	'info_gauche_admin_tech' => '<b>A aquela pagina, sonque los responsables del sit i pòdon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. D’unas que i a implican un procès d’autentificacion especific, que necessita un accès FTP al sit web.</p>', # MODIF
	'info_gauche_admin_vider' => '<b>A aquela pagina, sonque los responsables del sit i pòdon accedir.</b><p> Permet de trobar las diferentas foncions de mantenença tecnica. D’unas que i a implican un procès d’autentificacion especific, que necessita un accès FTP al sit web.</p>', # MODIF
	'info_gauche_auteurs' => 'Trobaretz aicí totes los autors del sit. La color de las icònas n’indica l’estatut (administrator = verd; redactor = jaune).',
	'info_gauche_auteurs_exterieurs' => 'Los autors exteriors, sens accès al sit, son indicats per una icòna blava; los autors escafats per un bordilhièr.', # MODIF
	'info_gauche_messagerie' => 'La messatjariá vos permet d’escambiar de messatges entre redactors, de servar de mementos (per vòstre usatge personal) o d’afichar d’anoncis sus la pagina d’acuèlh de l’espaci privat (se sètz administrator/tritz).',
	'info_gauche_statistiques_referers' => 'Aquela pagina presenta la lista dels <i>referidors</i>, valent a dire dels sits que contenon de ligams menant cap a vòstre quite sit, mas unicament per ièr e uèi: aquela lista s’actualiza cada 24 oras.',
	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí los vesitaires registrats
 dins l’espaci public del sit (forums amb abonament).',
	'info_generation_miniatures_images' => 'Congreacion de miniaturas dels imatges',
	'info_hebergeur_desactiver_envoi_email' => 'D’unes albergadors desactivan lo mandadís automatic
 d’e-mails dempuèi lors servidors. En aquel cas, las foncionalitats seguentas
 d’SPIP foncionaràn pas.',
	'info_hier' => 'ièr:',
	'info_identification_publique' => 'Vòstra identitat publica...',
	'info_image_process' => 'Volgatz seleccionar lo melhor metòde de fabricacion de las vinhetas en clicar sus l’imatge correspondent.',
	'info_image_process2' => '<b>N.B.</b> <i>Se cap d’imatge apareis pas, aladonc lo servidor qu’albèrga vòstre sit l’an pas configurat per utilizar d’aisinas talas. Se desiratz d’utilizar aquelas foncions, contactatz lo responsable tecnic e demandatz las extensions «GD» o «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imatges calculats automaticament',
	'info_informations_personnelles' => 'Informacions personalas',
	'info_inscription_automatique' => 'Inscripcion automatica de redactors novèls',
	'info_jeu_caractere' => 'Jòc de caractèrs del sit',
	'info_jours' => 'jorns',
	'info_laisser_champs_vides' => 'daissar aqueles camps vuèges)',
	'info_langues' => 'Lengas del sit',
	'info_ldap_ok' => 'L’autentificacion LDAP es installada.',
	'info_lien_hypertexte' => 'Ligam ipertèxt:',
	'info_liste_redacteurs_connectes' => 'Tièra dels redactors connectats',
	'info_login_existant' => 'Aquel login ja existís.',
	'info_login_trop_court' => 'Login tròp cort.',
	'info_logos' => 'Los lògos',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'Dins la meteissa rubrica',
	'info_message_en_redaction' => 'Vòstres messatges en cors de redaccion',
	'info_message_technique' => 'Messatge tecnic:',
	'info_messagerie_interne' => 'Messatjariá intèrna',
	'info_mise_a_niveau_base' => 'Mesa a nivèl de vòstra basa SQL',
	'info_mise_a_niveau_base_2' => '{{Atencion!}} Avètz installada una version
  dels fichièrs SPIP {anteriora} a la que i aviá
  abans sus aqueste sit: riscatz de pèrdre vòstra basa de donadas
   e vòstre sit foncionarà pas mai.<br />{{Tornatz installar los
  fichièrs d’SPIP.}}',
	'info_modifier_rubrique' => 'Modificar la rubrica:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'Mon sit SPIP',
	'info_moyenne' => 'mejana:',
	'info_multi_cet_article' => 'Lenga d’aqueste article:',
	'info_multi_langues_choisies' => 'Volgatz seleccionar çai sota las lengas que son a posita dels redactors de vòstre sit.
  Las lengas ja emplegadas dins vòstre sit (afichadas primièras) se pòdon pas desactivar.',
	'info_multi_secteurs' => '... sonque per las rubricas a la raiç del sit?',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom del destinatari',
	'info_nom_site' => 'Nom del vòstre sit',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sits,',
	'info_non_deplacer' => 'De desplaçar pas...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pòt mandar, regularament, l’anonci de las darrièras novetats del sit
 (articles e brèvas publicats recentament).',
	'info_non_envoi_liste_nouveautes' => 'Mandar pas la tièra de las novetats',
	'info_non_modifiable' => 'se pòt pas modificar',
	'info_non_suppression_mot_cle' => 'vòli pas suprimir aquel mot clau.',
	'info_notes' => 'Nòtas',
	'info_nouvel_article' => 'Article nòu',
	'info_nouvelle_traduction' => 'Revirada nòva:',
	'info_numero_article' => 'ARTICLE NUMÈRO:',
	'info_obligatoire_02' => '[Obligatòri]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dels vesitaires del sit public',
	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires',
	'info_options_avancees' => 'OPCIONS AVANÇADAS',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina proïbida',
	'info_par_nom' => 'per nom',
	'info_par_nombre_article' => 'per nombre d’articles',
	'info_par_statut' => 'per estatut',
	'info_par_tri' => '’(per @tri@)’',
	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
	'info_passes_identiques' => 'Los dos mots de santa Clara son pas identics.',
	'info_plus_cinq_car' => 'mai de 5 caractèrs',
	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
	'info_plus_trois_car' => '(mai de 3 caractèrs)',
	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_post_scriptum' => 'Post-scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'per',
	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totes los articles e brèvas (que tenon almens l’estatut "prepausat"). La cal dobrir, aquela possibilitat, als administrators sonque, a totes los redactors, o pas a degun?', # MODIF
	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
	'info_procedure_maj_version' => 'Cal lançar la procedura d’actualizacion per adaptar
 la basa de donadas a la version novèla d’SPIP.',
	'info_proxy_ok' => 'Ensag del proxy capitat.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Los vòstres articles publicats en linha',
	'info_question_accepter_visiteurs' => 'S’a las esqueletas de vòstre sit web se prevei lo registrament de vesitaires sens accès a l’espaci privat, volgatz activar l’opcion seguenta:',
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptatz que de redactors novèls s’inscrigan
 a partir del sit public? Se o acceptatz, los vesitaires se poiràn inscriure
 mercés a un formulari automatizat e alara accediràn a l’espaci privat per
 prepausar d’articles.<blockquote><i> Durant la fasa d’inscripcion, los utilizaires recebon un e-mail automatic
 que lor baila un còde d’accès al sit privat.
D’unes albergadors autorizan pas lo mandadís d’e-mails dempuèi lors servidors: en aquel cas, l’inscripcion automatica es
 impossibla.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Raiç del sit',
	'info_recharger_page' => 'Volgatz tornar cargar aquela pagina dins un momenton.',
	'info_recherche_auteur_zero' => '<b>Pas cap de resultat trobat per « @cherche_auteur@ ».',
	'info_recommencer' => 'Volgatz tornar començar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'qu’accedís a l’espaci privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'EN CORS DE REDACCION',
	'info_redirection' => 'Redireccion',
	'info_refuses' => 'Vòstres articles refusats',
	'info_reglage_ldap' => 'Opcions: <b>Reglatge de l’importacion LDAP</b>',
	'info_renvoi_article' => '<b>Redireccion.</b> Aquel article remanda a la pagina:',
	'info_reserve_admin' => 'Sonque los administrators pòdon modificar aquela adreiça.',
	'info_restreindre_rubrique' => 'Restrénher la gestion a la rubrica:',
	'info_resultat_recherche' => 'Resultats de la cèrca:',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas trobadas',
	'info_sans_titre' => 'Sens títol',
	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sota lo camin d’accès dins l’annuari:',
	'info_signatures' => 'signaturas',
	'info_site' => 'Sit',
	'info_site_2' => 'sit: ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referenciat',
	'info_site_web' => 'SIT WEB:', # MODIF
	'info_sites' => 'sits',
	'info_sites_lies_mot' => 'Los sits referenciats ligats a aquel mot clau',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sits trobats',
	'info_sous_titre' => 'Sostítol:',
	'info_statut_administrateur' => 'Administrator',
	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
	'info_statut_auteur_a_confirmer' => 'Inscripcion de confirmar',
	'info_statut_auteur_autre' => 'Autre estatut :',
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatut predefinit dels utilizaires importats',
	'info_statut_utilisateurs_2' => 'Causissètz l’estatut d’atribuir a las personas presentas dins l’annuari LDAP quora se connèctan pel primièr còp. Poiretz puèi modificar aquel estatut per cada autor un cas per un.',
	'info_suivi_activite' => 'Seguit de l’activitat editoriala',
	'info_surtitre' => 'Subretítol:',
	'info_syndication_integrale_1' => 'Vòstre sit prepausa de fichièrs de sindicacion (véser « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Desiratz transmetre l’integralitat dels articles, o ne difusar pas qu’un resumit de qualques centenas de caractèrs ?',
	'info_table_prefix' => 'Podètz cambiar lo prefix del nom de las taulas de donadas (aquò es indispensable per installar mai d’un sit dins la meteissa basa de donadas). Aquel prefix s’esriu en letras minusculas, non accentuadas, e sens espaci.',
	'info_taille_maximale_vignette' => 'Talha maximala de las vinhetas congreadas pel sistèma:',
	'info_terminer_installation' => 'Ara podètz acabar la procedura d’installacion estandard.',
	'info_texte' => 'Tèxt',
	'info_texte_explicatif' => 'Tèxt explicatiu',
	'info_texte_long' => '(lo tèxt es long: apareis doncas en tròces distints que se tornaràn empegar un còp validats.)',
	'info_texte_message' => 'Tèxt del vòstre messatge:', # MODIF
	'info_texte_message_02' => 'Tèxt del messatge',
	'info_titre' => 'Títol:',
	'info_total' => 'total: ',
	'info_tous_articles_en_redaction' => 'Totes los articles en cors de redaccion',
	'info_tous_articles_presents' => 'Totes los articles publicats dins aquela rubrica',
	'info_tous_les' => 'totes los:',
	'info_tout_site' => 'Tot lo sit ',
	'info_tout_site2' => 'An pas revirat l’article dins aquela lenga.',
	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mas an portat puèi de modificacions a l’article de referéncia. Cal actualizar la revirada.',
	'info_tout_site4' => 'An revirat l’article dins aquela lenga, e la revirada es actualizada.',
	'info_tout_site5' => 'Article original.',
	'info_tout_site6' => '<b>Atencion:</b> sonque los articles originals s’afichan.
Las reviradas s’assòcian a l’original,
una color indica lor estat:',
	'info_travail_colaboratif' => 'Trabalh collaboratiu suls articles',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'una rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL :',
	'info_urlref' => 'Ligam ipertèxt:',
	'info_utilisation_spip' => 'Ara podètz començar d’utilizar lo sistèma de publicacion assistida...',
	'info_visites_par_mois' => 'Afichatge per mes:',
	'info_visiteur_1' => 'Vesitaire',
	'info_visiteur_2' => 'del sit public',
	'info_visiteurs' => 'Vesitaires',
	'info_visiteurs_02' => 'Vesitaires del sit public',
	'install_adresse_base_hebergeur' => 'Adreiça de la basa de donadas atribuida per l’albergador',
	'install_echec_annonce' => 'L’installacion capitarà mal, o abotirà a un sit non foncional...',
	'install_extension_mbstring' => 'SPIP fonciona pas amb:',
	'install_extension_php_obligatoire' => 'SPIP exigís l’extension php:',
	'install_login_base_hebergeur' => 'Identificant (login) de connexion atribuit per l’albergador',
	'install_nom_base_hebergeur' => 'Nom de la basa atribuit per l’albergador:',
	'install_pass_base_hebergeur' => 'Senhal de connexion (password) atribuit per l’albergador',
	'install_php_version' => 'PHP version @version@ insuffisanta (minimum = @minimum@)',
	'install_select_langue' => 'Seleccionatz una lenga puèi clicatz lo boton « seguent » per amodar la procedura d’installacion.',
	'install_table_prefix_hebergeur' => 'Prefix de taula atribuit per l’albergador:',
	'intem_redacteur' => 'redactor',
	'item_accepter_inscriptions' => 'Acceptar las inscripcions',
	'item_activer_messages_avertissement' => 'Activar los messatges d’avertiment',
	'item_administrateur_2' => 'administrator',
	'item_afficher_calendrier' => 'Afichar dins lo calendièr',
	'item_autoriser_syndication_integrale' => 'Difusar l’integralitat dels articles dins los fichièrs de sindicacion',
	'item_choix_administrateurs' => 'los administrators',
	'item_choix_generation_miniature' => 'Congrear automaticament las miniaturas dels imatges.',
	'item_choix_non_generation_miniature' => 'Congrear pas de miniaturas dels imatges.',
	'item_choix_redacteurs' => 'los redactors',
	'item_choix_visiteurs' => 'los vesitaires del sit public',
	'item_creer_fichiers_authent' => 'Crear de fichièrs .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'als articles',
	'item_mots_cles_association_rubriques' => 'a las rubricas',
	'item_mots_cles_association_sites' => 'als sits referenciats o sindicats',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Acceptar pas las inscripcions',
	'item_non_activer_messages_avertissement' => 'Pas cap de messatge d’avertiment',
	'item_non_afficher_calendrier' => 'De pas afichar dins lo calendièr',
	'item_non_autoriser_syndication_integrale' => 'Ne difusar pas qu’un resumit',
	'item_non_creer_fichiers_authent' => 'Crear pas aqueles fichièrs',
	'item_non_publier_articles' => 'Publicar pas los articles abans la data de publicacion prevista.',
	'item_nouvel_auteur' => 'Autor nòu',
	'item_nouvelle_rubrique' => 'Rubrica nòva',
	'item_oui' => 'Òc',
	'item_publier_articles' => 'Publicar los articles, quina que siá sa data de publicacion',
	'item_reponse_article' => 'Responsa a l’article',
	'item_visiteur' => 'vesitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Apondre aquel autor',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOM DEL SIT :',
	'lien_retirer_auteur' => 'Levar l’autor',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'O desplegar tot',
	'lien_tout_replier' => 'Tornar plegar',
	'lien_tout_supprimer' => 'Suprimir tot',
	'lien_trier_nom' => 'Triar per nom',
	'lien_trier_nombre_articles' => 'Triar per nombre d’articles',
	'lien_trier_statut' => 'Triar per estatut',
	'lien_voir_en_ligne' => 'VEIRE EN LINHA :',
	'logo_article' => 'LÒGO DE L’ARTICLE', # MODIF
	'logo_auteur' => 'LÒGO DE L’AUTOR', # MODIF
	'logo_rubrique' => 'LÒGO DE LA RUBRICA', # MODIF
	'logo_site' => 'LÒGO D’AQUEL SIT', # MODIF
	'logo_standard_rubrique' => 'LÒGO ESTANDARD DE LAS RUBRICAS', # MODIF
	'logo_survol' => 'LÒGO PEL SUBREVÒL', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Causida de vòstra basa',
	'module_fichier_langue' => 'Fichièr de lenga',
	'module_raccourci' => 'Acorcha',
	'module_texte_affiche' => 'Tèxt afichat',
	'module_texte_explicatif' => 'Podètz inserir las acorchas seguentas dins las esqueletas de vòstre sit public. Se reviraràn automaticament  dins las diferentas lengas per las qualas existís un fichièr de lenga.',
	'module_texte_traduction' => 'Lo fichièr de lenga «@module@» es disponible en:',
	'mois_non_connu' => 'non conegut',

	// O
	'onglet_repartition_actuelle' => 'd’aquesta passa',

	// P
	'pas_de_proxy_pour' => 'Al besonh, indicatz las maquinas o domènis per qual aquel proxy se deu pas aplicar (per exemple : @exemple@)',
	'plugin_etat_developpement' => 'en cors de desvolopament',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'estable',
	'plugin_etat_test' => 'a l’ensag',
	'plugin_impossible_activer' => 'Impossible d’activar l’ajuston @plugin@',
	'plugin_necessite_plugin' => 'Demanda l’ajuston @plugin@ en version @version@ al mens.', # MODIF
	'plugin_necessite_spip' => 'Demanda SPIP en version @version@ al mens.',
	'plugins_liste' => 'Tièra dels ajustons',
	'protocole_ldap' => 'Version del protocòl :',

	// R
	'repertoire_plugins' => 'Repertòri :',
	'required' => '[Obligatòri]', # MODIF

	// S
	'statut_admin_restreint' => '(admin. restrench)', # MODIF

	// T
	'taille_cache_image' => 'Los imatges qu’SPIP a calculat automaticament (vinhetas dels documents, títols presentats en forma grafica, foncions matematicas en format TeX...) ocupan dins lo repertòri @dir@ un total de @taille@.',
	'taille_cache_infinie' => 'Aquel sit prevei pas cap de limitacion de talha del repertòri de l’escondedor.',
	'taille_cache_maxi' => 'SPIP assaja de limitar la talha del repertòri de l’escondedor d’aquel sit a <b>@octets@</b> de donadas aperaquí.',
	'taille_cache_octets' => 'Ara la talha de l’escondedor compassa @octets@.', # MODIF
	'taille_cache_vide' => 'L’escondedor es void.',
	'taille_repertoire_cache' => 'Talha del repertòri escondedor',
	'text_article_propose_publication' => 'Article prepausat per la publicacion. Esitetz pas de donar vòstre vejaire gràcias al forum estacat a aquel article (en bas de pagina).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'D’unes servidors LDAP accèptan pas ges d’accès anonim. En aquel cas, cal especificar un identificant d’accès inicial per poder puèi cercar d’informacions dins l’annuari. Pasmens, los camps seguents se poiràn daissar vuèges dins la màger part dels cases.',
	'texte_admin_effacer_01' => 'Aquela comanda escafa <i>tot</i> lo contengut de la basa de donadas,
 incluses <i>totes</i> los accèsses redactors e administrators. Un còp que l’auretz executada, auretz de tornar lançar l’installacion d’SPIP per tornar crear una basa novèla e mai un primièr accès administrator.',
	'texte_adresse_annuaire_1' => '(Se vòstre annuari es installat sus la meteissa maquina qu’aquel sit web, s’agís probable de "localhost".)',
	'texte_ajout_auteur' => 'L’autor seguent es estat apondut a l’article:',
	'texte_annuaire_ldap_1' => 'S’accedissètz a un annuari (LDAP), lo podètz utilizar per importar automaticament d’utilizaires jos SPIP.',
	'texte_article_statut' => 'Aquel article es:',
	'texte_article_virtuel' => 'Article virtual',
	'texte_article_virtuel_reference' => '<b>Article virtual:</b> article referenciat dins vòstre sit SPIP, mas redirigit cap a una autra URL. Per suprimir la redireccion, escafatz l’URL çai subre.',
	'texte_aucun_resultat_auteur' => 'Cap de resultat per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aqueste sit vos pòt indicar de contunh la tièra dels redactors connectats, çò que vos permet d’escambiar de messatges en dirècte. Podètz decidir d’aparéisser pas dins aquela lista (sètz "invisible/a" pels autres utilizaires).',
	'texte_auteurs' => 'LOS AUTORS',
	'texte_choix_base_1' => 'Causissètz vòstra basa:',
	'texte_choix_base_2' => 'Lo servidor SQL conten mai d’una basa de donadas.',
	'texte_choix_base_3' => '<b>Causissètz</b> çai sota la que vòstre albergador vos a atribuida:',
	'texte_choix_table_prefix' => 'Prefix de las taulas :',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_connexion_mysql' => 'Consultatz las informacions que vòstre albergador fornís: i devètz trobar los còdes de connexion al servidor SQL.', # MODIF
	'texte_contenu_article' => '(Contengut de l’article en qualques mots.)',
	'texte_contenu_articles' => 'Segon la maqueta que vòstre sit a adoptada, podètz decidir
 que d’unes elements dels articles s’utilizen pas.
 Utilizatz la tièra çai jos per indicar quines elements son disponibles.',
	'texte_crash_base' => 'Se vòstra basa de donadas a
 abocat, podètz ensajar una reparacion
 automatica.',
	'texte_creer_rubrique' => 'Abans de poder escriure d’articles,<br /> devètz crear una rubrica.',
	'texte_date_creation_article' => 'DATA DE CREACION DE L’ARTICLE:',
	'texte_date_publication_anterieure' => 'Data de redaccion anteriora:',
	'texte_date_publication_anterieure_nonaffichee' => 'Afichar pas cap de data de redaccion anteriora.',
	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
	'texte_descriptif_rapide' => 'Descriptiu rapid',
	'texte_effacer_base' => 'Escafar la basa de donadas SPIP',
	'texte_en_cours_validation' => 'Se prepausa de publicar los articles e brèvas çai sota. Esitetz pas de donar lo vòstre vejaire gràcias als forums que i son estacats.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Podètz enriquir la compaginacion del vòstre tèxt en utilizar d’"acorchas tipograficas".',
	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichièrs especials  <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> dins lo repertòri @dossier@?</b><p>
  Aqueles fichièrs vos pòdon servir per restrénher l’accès als autors
  e administrators endacòm mai dins vòstre sit
  (programa extèrne d’estadisticas, per exemple).<p>
 Se vos servís pas, podètz daissar aquesta opcion
  a sa valor predefinida (pas cap de creacion
  dels fichièrs).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Ara lo sistèma vos crearà un accès personalizat al sit.',
	'texte_informations_personnelles_2' => '(Nòta: se s’agís d’una reïnstallacion, e se vòstre accès fonciona encara, podètz', # MODIF
	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
	'texte_jeu_caractere' => 'S’aconselha d’emplegar, sus vòstre sit, l’alfabet universal  (<tt>utf-8</tt>) :permet d’afichar totas las lengas, e pausa pas pus de problèmas de compatibilitat amb los navigators modèrnes.',
	'texte_jeu_caractere_3' => 'Vòstre sit es per ara installat amb lo jòc de caractèrs :',
	'texte_jeu_caractere_4' => 'En cas qu’aquò corresponda pas a la realitat de vòstras donadas), o <em>que comencetz a pro pena aquel sit</em> e desiretz causir un autre jòc de caractèrs, indicatz-lo aicí : ',
	'texte_login_ldap_1' => '(Daissar vuèg per un accès anonim, o picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
	'texte_login_precaution' => 'Atencion! Aquò’s lo login amb lo qual sètz ara connectat/ada. 
 Utilizatz aqueste formulari amb precaucion...',
	'texte_mise_a_niveau_base_1' => ' Venètz d’actualizar los fichièrs SPIP.
 Ara cal metre a nivèl la basa de donadas
 del sit.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en mai d’una lenga, amb una navigacion complèxa, podètz apondre un menut per causir la lenga dels articles e/o de las rubricas, en foncion de l’organizacion de vòstre sit.', # MODIF
	'texte_multilinguisme_trad' => 'Podètz tanben activar un sistèma de gestion dels ligams entre las diferentas reviradas d’un article.', # MODIF
	'texte_non_compresse' => '<i>non comprimit</i> (pr’amor que vòstre servidor supòrta pas aquela foncionalitat)',
	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se sètz webmèstre/webmèstra del sit, volgatz escafar lo fichièr @connect@ e tornar prene l’installacion per tal d’actualizar vòstres paramètres de connexion a la basa de donadas.<p> (NB: s’avètz desmembrat vòstres paramètres de connexion, espepissatz lo fichièr  @connect@ abans de lo suprimir...)</p>', # MODIF
	'texte_operation_echec' => 'Tornatz a la pagina precedenta, causissètz una autra basa o creatz-ne una novèla. Verificatz las informacions que vòstre albergador a fornidas.',
	'texte_plus_trois_car' => 'mai de 3 caractèrs',
	'texte_plusieurs_articles' => 'Mai d’un autor trobat per "@cherche_auteur@":',
	'texte_port_annuaire' => '(La valor indicada coma predefinida conven en general.)',
	'texte_presente_plugin' => 'Aquela pagina lista los ajustons disponibles sus lo sit. Podètz activar los ajustons necessaris en marcar la casa correspondenta.',
	'texte_proposer_publication' => 'Quora auretz acabat vòstre article,<br /> poiretz prepausar que siá publicat.',
	'texte_proxy' => 'Dins d’unes cases (intranet, rets protegidas...), los sits distants (documentacion d’SPIP, sits sindicats, etc.) son pas accessibles qu’a travèrs d’un <i>proxy HTTP</i>.
  En aquel cas, marcatz çai sota son adreiça, jos la forma@proxy_en_cours@. En general,
  daissaretz vuèja aquela casa.',
	'texte_publication_articles_post_dates' => 'Cossí SPIP se deu comportar fàcia als articles que lor
  data de publicacion es fixada a una 
  escasença futura?',
	'texte_rappel_selection_champs' => '[Oblidetz pas de seleccionar aquel camp corrèctament.]',
	'texte_recalcul_page' => 'Se volètz
tornar calcular sonque una pagina, passatz puslèu per l’espaci public e utilizatz lo  boton "tornar calcular".',
	'texte_recuperer_base' => 'Reparar la basa de donadas',
	'texte_reference_mais_redirige' => 'article referenciat dins vòstre sit SPIP, mas redirigit cap a una autra URL.',
	'texte_requetes_echouent' => '<b>Quora d’unas requistas SQL abocan
  sistematicament e sens rason aparenta, se pòt
  qu’aquò venga de la quita basa de donadas.  </b><p>
  SQL ten la facultat de reparar sas
  taulas quora un accident las
 a esquintadas. Aicí podètz ensajar aquela reparacion; se 
  capita pas, servatz una còpia de l’afichatge, que conten
 benlèu d’indicis de çò que va pas...</p><p>
  Se lo problèma persistís, contactatz vòstre
  albergador.</p>', # MODIF
	'texte_selection_langue_principale' => 'Podètz seleccionar çai sota la "lenga principala" del sit. Aquela causida vos obliga pas -grand gaug- d’escriure vòstres articles dins la lenga seleccionada, mas permet de determinar:
 <ul><li> lo format predefinit de las datas sul sit public;</li>
 <li> la natura del motor tipografic que SPIP deu utilizar pel rendut dels tèxtes;</li>
 <li> la lenga utilizada dins los formularis del sit public;</li>
 <li> la lenga presentada coma predefinida dins l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Sostítol',
	'texte_statistiques_visites' => '(barras escuras:  dimenge / corba escura: evolucion de la mejana)',
	'texte_statut_attente_validation' => 'en espèra de validacion',
	'texte_statut_publies' => 'publicats en linha',
	'texte_statut_refuses' => 'refusats',
	'texte_suppression_fichiers' => 'Utilizatz aquela comanda per suprimir totes los fichièrs que se tròban
dins l’escondedor SPIP. Aquò permet per exemple de forçar un calcul nòu de totas las paginas
s’avètz bravament modificat lo grafisme o l’estructura del sit.',
	'texte_sur_titre' => 'Subretítol',
	'texte_table_ok' => ': aquesta taula es condrecha.',
	'texte_tentative_recuperation' => 'Ensag de reparacion',
	'texte_tenter_reparation' => 'Ensajar de reparar la basa de donadas',
	'texte_test_proxy' => 'Per ensajar aquel proxy, indicatz aicí l’adreiça d’un sit web
    que lo voldriatz esprovar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatòri]',
	'texte_travail_article' => '@nom_auteur_modif@ a trabalhat sus aquel article fa @date_diff@ minutas',
	'texte_travail_collaboratif' => 'Quora es frequent que mai d’un redactor 
  trabalhe sul meteis article, lo sistèma
  pòt afichar los articles recentament "dobèrts"
  per tal d’evitar las modificacions simultanèas.
  Aquela opcion es desactivada de manièra predefinida
  per tal d’evitar d’afichar de messatges d’avertiment
  intempestius.',
	'texte_vide' => 'vuèg',
	'texte_vider_cache' => 'Vojar l’escondedor',
	'titre_admin_tech' => 'Mantenença tecnica',
	'titre_admin_vider' => 'Mantenença tecnica',
	'titre_cadre_afficher_article' => 'Afichar los articles',
	'titre_cadre_afficher_traductions' => 'Afichar l’estat de las reviradas per las lengas seguentas:',
	'titre_cadre_ajouter_auteur' => 'APONDRE UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Dintre la rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NUMÈRO',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_fonctions' => 'Configuracion del sit',
	'titre_configuration' => 'Configuracion del sit',
	'titre_connexion_ldap' => 'Opcions: <b>Vòstra connexion LDAP</b>',
	'titre_groupe_mots' => 'GROP DE MOTS:',
	'titre_langue_article' => 'LENGA DE L’ARTICLE', # MODIF
	'titre_langue_rubrique' => 'LENGA DE LA RUBRICA', # MODIF
	'titre_langue_trad_article' => 'LENGA E REVIRADAS DE L’ARTICLE',
	'titre_les_articles' => 'LOS ARTICLES',
	'titre_naviguer_dans_le_site' => 'Navigar pel sit...',
	'titre_nouvelle_rubrique' => 'Rubrica novèla',
	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Los articles',
	'titre_page_articles_tous' => 'Tot lo sit',
	'titre_page_calendrier' => 'Calendièr @nom_mois@ de @annee@',
	'titre_page_config_contenu' => 'Configuracion del sit',
	'titre_page_delete_all' => 'supression totala e irreversibla',
	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
	'titre_page_statistiques_referers' => 'Estadisticas (ligams intrants)',
	'titre_page_upgrade' => 'Mesa a nivèl d’SPIP',
	'titre_publication_articles_post_dates' => 'Publicacion dels articles pòstdatats',
	'titre_reparation' => 'Reparacion',
	'titre_suivi_petition' => 'Seguit de las peticions',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Totas las versions d’aquel article:',
	'trad_delier' => 'Ligar pas mai aqueste article a sas reviradas ', # MODIF
	'trad_lier' => 'Aqueste article es una revirada de l’article numèro:',
	'trad_new' => 'Escriure una revirada novèla d’aqueste article', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Error : lo jòc de caractèrs @charset@ es pas suportat.',

	// V
	'version' => 'Version :'
);
